@@ -15,27 +15,32 @@ def create_umap_plot(data:np.array, targets:np.array = None, reducer_seed:int =
     return umap_plot.figure
 
 
-def create_conf_matrix_plot(data:np.array, targets: np.array,plot_labels='auto'):
+def create_conf_matrix_plot(data:np.array, targets: np.array, plot_labels='auto', title:str=None):
     conf_matrix = confusion_matrix(data, targets, normalize='all')
     conf_plot = seaborn.heatmap(conf_matrix, annot=True, cmap="Blues",
                                 xticklabels=plot_labels, yticklabels=plot_labels)
+    
+    # Layout stuff
+    if title is not None:
+        plt.title(f'{title}', fontsize=18) 
     plt.tight_layout()
+    
     return conf_plot.figure
 
 
-def plot_UMAP(feature_vec:np.array, label_vec:np.array, set_name=None, reducer_seed:int = 42):
+def plot_UMAP(feature_vec:np.array, label_vec:np.array, title=None, reducer_seed:int = 42):
     # -- scale and calculate UMAP embedding
     scaled_data = StandardScaler().fit_transform(feature_vec)
     reducer = umap.UMAP(random_state=reducer_seed)
     embedding = reducer.fit_transform(scaled_data)
 
     # -- plot
-    return _2dplot_scatter(embedding, label_vec, set_name)
+    return _2dplot_scatter(embedding, label_vec, title)
 
 
-def plot_TSNE(feature_vec:np.array, label_vec:np.array, set_name:Optional[str] = None, reducer_seed:int = 42):
+def plot_TSNE(feature_vec:np.array, label_vec:np.array, title:Optional[str] = None, reducer_seed:int = 42):
     embedding = TSNE(n_components=2, random_state=reducer_seed).fit_transform(feature_vec)
-    return _2dplot_scatter(embedding, label_vec, set_name)
+    return _2dplot_scatter(embedding, label_vec, title)
 
 
 def _2dplot_scatter(data:np.array, label:np.array, title:Optional[str] = None, marker_size:int = 3):
@@ -50,8 +55,7 @@ def _2dplot_scatter(data:np.array, label:np.array, title:Optional[str] = None, m
     
     plt.gca().set_aspect('equal', 'datalim')
     plt.grid()
-    plt.title('TSNE projection of the embedding', fontsize=18)
     if title is not None:
-        plt.title(f'TSNE projection of the {title} embedding', fontsize=18)       
+        plt.title(f'{title}', fontsize=18)       
 
     return fig
\ No newline at end of file
